@@ -1,7 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2007 Brian Pepple <bpepple@fedoraproject.org>
- *                    Daniel Morales <daniminas@gmail.com>
+ * Copyright (C) 2007-2008 Brian Pepple <bpepple@fedoraproject.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,14 +16,17 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
+ *
+ * Authors: Brian Pepple <bpepple@fedoraproject.org>
+ *			Daniel Morales <daniminas@gmail.com>
  */
 
 #include <config.h>
+#include <sys/stat.h>
+#include <string.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/libgnomeui.h>
-
 #include <libnotify/notify.h>
 
 #include <libtwitux/twitux-debug.h>
@@ -36,9 +38,11 @@
 
 #include "twitux.h"
 #include "twitux-about.h"
+#include "twitux-account-dialog.h"
 #include "twitux-app.h"
 #include "twitux-geometry.h"
 #include "twitux-glade.h"
+#include "twitux-hint.h"
 #include "twitux-network.h"
 #include "twitux-preferences.h"
 #include "twitux-send-message-dialog.h"
@@ -102,6 +106,11 @@ static void     twitux_app_init			         (TwituxApp             *app);
 static void     app_finalize                     (GObject               *object);
 static void     app_restore_main_window_geometry (GtkWidget             *main_window);
 static void     app_setup                        (void);
+static gboolean app_main_window_quit_confirm 	 (TwituxApp             *app,
+												  GtkWidget             *window);
+static void     app_main_window_quit_confirm_cb	 (GtkWidget             *dialog,
+												  gint                   response,
+												  TwituxApp             *app);
 static void     app_main_window_destroy_cb       (GtkWidget             *window,
 												  TwituxApp             *app);
 static gboolean app_main_window_delete_event_cb  (GtkWidget             *window,
@@ -154,7 +163,7 @@ static void     app_login                        (void);
 static void     app_retrieve_default_timeline    (void);
 static void     app_status_icon_create_menu      (void);
 static void     app_status_icon_create           (void);
-static void     app_check_dir                    ();
+static void     app_check_dir                    (void);
 static gboolean configure_event_timeout_cb       (GtkWidget             *widget);
 static gboolean app_window_configure_event_cb    (GtkWidget             *widget,
 												  GdkEventConfigure     *event,
@@ -219,11 +228,12 @@ static void
 app_setup (void)
 {
 	TwituxAppPriv    *priv;
-	TwituxConf       *conf;
+	TwituxConf		 *conf;
 	GladeXML         *glade;
 	GtkWidget        *scrolled_window;
 	GtkWidget        *expand_vbox;
 	gboolean          login;
+	gboolean		  hidden;
 
 	twitux_debug (DEBUG_DOMAIN_SETUP, "Beginning....");
 
@@ -231,7 +241,7 @@ app_setup (void)
 
 	/* Set up interface */
 	twitux_debug (DEBUG_DOMAIN_SETUP, "Initialising interface");
-	glade = twitux_glade_get_file ("main.glade",
+	glade = twitux_glade_get_file ("main_window.glade",
 								   "main_window",
 								   NULL,
 								   "main_window", &priv->window,
@@ -253,6 +263,7 @@ app_setup (void)
 						  app,
 						  "main_window", "destroy", app_main_window_destroy_cb,
 						  "main_window", "delete_event", app_main_window_delete_event_cb,
+						  "main_window", "configure_event", app_window_configure_event_cb,
 						  "twitter_connect", "activate", app_twitter_connect_cb,
 						  "twitter_disconnect", "activate", app_twitter_disconnect_cb,
 						  "twitter_new_message", "activate", app_twitter_new_msg_cb,
@@ -276,7 +287,7 @@ app_setup (void)
 	app_connection_items_setup (glade);
 	g_object_unref (glade);
 
-	/* Let's hide the main window */
+	/* Let's hide the main window, while we are setting up the ui */
 	gtk_widget_hide (GTK_WIDGET (priv->window));
 
 #ifdef HAVE_DBUS
@@ -289,6 +300,9 @@ app_setup (void)
 				  "Configuring notification area widget...");
 	app_status_icon_create_menu ();
 	app_status_icon_create ();
+	
+	/* Set the main window geometry */ 	 
+	app_restore_main_window_geometry (priv->window);
 
 	/* Set-up list view */
 	priv->listview = twitux_tweet_list_new ();
@@ -310,14 +324,23 @@ app_setup (void)
 	/* Check Twitux directory and images cache */
 	app_check_dir ();
 
-	/* Set the main window geometry */ 	 
-	app_restore_main_window_geometry (priv->window);
-
-	/* Show the main window */
-	gtk_widget_show (GTK_WIDGET (priv->window));
+	/* Assign the conf object to a variable since we're using it more than once */
+	conf = twitux_conf_get ();
+	
+	/* Get the gconf value for whether the window should be hidden on start-up */
+	twitux_conf_get_bool (conf,
+						  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
+						  &hidden);
+	
+	/* Ok, set the window state based on the gconf value */				  
+	if (hidden) {
+		gtk_widget_hide (priv->window);
+	} else {
+		gtk_widget_show (priv->window);
+	}
 
 	/*Check to see if we should automatically login */
-	twitux_conf_get_bool (twitux_conf_get (),
+	twitux_conf_get_bool (conf,
 						  TWITUX_PREFS_AUTH_AUTO_LOGIN,
 						  &login);
 
@@ -325,6 +348,47 @@ app_setup (void)
 		app_login ();
 }
 
+static gboolean
+app_main_window_quit_confirm (TwituxApp *app,
+							  GtkWidget *window)
+{
+	TwituxAppPriv *priv;
+	GtkWidget *dialog;
+	
+	priv = GET_PRIV (app);
+	
+	dialog = gtk_message_dialog_new_with_markup	(GTK_WINDOW (twitux_app_get_window ()),
+												 0,
+												 GTK_MESSAGE_WARNING,
+												 GTK_BUTTONS_OK_CANCEL,
+												 "<b>%s</b>",
+												 _("Do you really want to quit?"));
+
+	g_signal_connect (dialog, "response",
+					  G_CALLBACK (app_main_window_quit_confirm_cb),
+					  app);
+
+	gtk_widget_show (dialog);
+
+	return TRUE;
+}
+
+static void
+app_main_window_quit_confirm_cb (GtkWidget *dialog,
+								 gint       response,
+								 TwituxApp *app)
+{
+	TwituxAppPriv *priv;
+
+	priv = GET_PRIV (app);
+
+	gtk_widget_destroy (dialog);
+
+	if (response == GTK_RESPONSE_OK) {
+		gtk_widget_destroy (priv->window);
+	}
+}
+
 static void
 app_main_window_destroy_cb (GtkWidget *window, TwituxApp *app)
 {
@@ -350,7 +414,46 @@ app_main_window_delete_event_cb (GtkWidget *window,
 
 	priv = GET_PRIV (app);
 
-	/* TODO: We need to check the tray before quiting. */
+	if (gtk_status_icon_is_embedded (priv->status_icon)) {
+		twitux_hint_show (TWITUX_PREFS_HINTS_CLOSE_MAIN_WINDOW,
+						  _("Twitux is still running, it is just hidden."),
+						  _("Click on the notification area icon to show Twitux."),
+						   GTK_WINDOW (twitux_app_get_window ()),
+						   NULL, NULL);
+		
+		twitux_app_set_visibility (FALSE);
+
+		return TRUE;
+	}
+
+	if (app_main_window_quit_confirm (app, window)) {
+		/* Don't quit if we have messages open */
+		return TRUE;
+	}
+	
+	if (twitux_hint_dialog_show (TWITUX_PREFS_HINTS_CLOSE_MAIN_WINDOW,
+								_("You were about to quit!"),
+								_("Since no system or notification tray has been "
+								"found, this action would normally quit Twitux.\n\n"
+								"This is just a reminder, from now on, Twitux will "
+								"quit when performing this action unless you uncheck "
+								"the option below."),
+								GTK_WINDOW (twitux_app_get_window ()),
+								NULL, NULL)) {
+		/* Shown, we don't quit because the callback will
+		 * decide that based on the YES|NO response from the
+		 * question we are about to ask, since this behaviour
+		 * is new.
+		 */
+		return TRUE;
+	}
+
+	/* At this point, we have checked we have:
+	 *   - No tray
+	 *   - Have NOT shown the hint
+	 *
+	 * So we just quit.
+	 */
 
 	return FALSE;
 }
@@ -391,18 +494,36 @@ twitux_app_toggle_visibility (void)
 		gtk_widget_hide (priv->window);
 
 		twitux_conf_set_bool (twitux_conf_get (),
-							  TWITUX_PREFS_UI_WINDOW_HIDE,
+							  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
 							  TRUE);
 	} else {
 		twitux_geometry_load_for_main_window (priv->window);
 		twitux_window_present (GTK_WINDOW (priv->window), TRUE);
 
 		twitux_conf_set_bool (twitux_conf_get (),
-							  TWITUX_PREFS_UI_WINDOW_HIDE,
+							  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
 							  FALSE);
 	}
 }
 
+void
+twitux_app_set_visibility (gboolean visible)
+{
+	GtkWidget *window;
+
+	window = twitux_app_get_window ();
+
+	twitux_conf_set_bool (twitux_conf_get (),
+						  TWITUX_PREFS_UI_MAIN_WINDOW_HIDDEN,
+						  !visible);
+
+	if (visible) {
+		twitux_window_present (GTK_WINDOW (window), TRUE);
+	} else {
+		gtk_widget_hide (window);
+	}
+}
+
 static void
 app_twitter_connect_cb (GtkWidget *widget,
 						TwituxApp *app)
@@ -658,7 +779,7 @@ app_status_icon_create_menu (void)
 
 	priv = GET_PRIV (app);
 
-	glade = twitux_glade_get_file ("main.glade",
+	glade = twitux_glade_get_file ("tray_menu.glade",
 								   "tray_menu",
 								   NULL,
 								   "tray_menu", &priv->popup_menu,
@@ -768,8 +889,6 @@ app_login (void)
 	gchar         *username;
 	gchar         *password;
 
-	priv = GET_PRIV (app);
-
 #ifdef HAVE_DBUS
 	gboolean connected = TRUE;
 
@@ -781,6 +900,8 @@ app_login (void)
 		return;
 	}
 #endif
+	
+	priv = GET_PRIV (app);
 
 	conf = twitux_conf_get ();
 	twitux_conf_get_string (conf,
@@ -829,7 +950,7 @@ app_retrieve_default_timeline (void)
 	/* This shouldn't happen, but just in case */
 	if (G_STR_EMPTY (timeline)) {
 		g_warning ("Default timeline in not set");
-		timeline = g_strdup (TWITUX_API_TIMELINE_PUBLIC);
+		timeline = g_strdup (TWITUX_API_TIMELINE_FRIENDS);
 	}
 
 	if (strcmp (timeline, TWITUX_API_TIMELINE_FRIENDS) == 0) {
@@ -860,10 +981,10 @@ app_check_dir (void)
 {
 	gchar    *file;
 
-	file = gnome_util_home_file (TWITUX_CACHE_IMAGES);
+	file = g_build_filename (g_get_home_dir (), ".gnome2", TWITUX_CACHE_IMAGES, NULL);
 
 	if (!g_file_test (file, G_FILE_TEST_EXISTS|G_FILE_TEST_IS_DIR)) {
-		twitux_debug (DEBUG_DOMAIN_SETUP, "Makeing directory: %s", file);
+		twitux_debug (DEBUG_DOMAIN_SETUP, "Making directory: %s", file);
 		g_mkdir_with_parents (file, S_IRUSR|S_IWUSR|S_IXUSR);
 	}
 
@@ -998,8 +1119,8 @@ void
 twitux_app_add_friend (TwituxUser *user)
 {
 	TwituxAppPriv *priv;
-	GtkWidget *menu;
-	GtkWidget *item;
+	GtkWidget	  *menu;
+	GtkWidget	  *item;
 
 	priv = GET_PRIV (app);
 
@@ -1063,18 +1184,19 @@ twitux_app_set_image (const gchar *file,
                       GtkTreeIter iter)
 {
 	GtkListStore *store;
-	GdkPixbuf *pixbuf;
-	GError *error = NULL;
+	GdkPixbuf	 *pixbuf;
+	GError		 *error = NULL;
 
 	pixbuf = gdk_pixbuf_new_from_file (file, &error);
-	store = twitux_tweet_list_get_store ();
 
 	if (!pixbuf){
 		twitux_debug (DEBUG_DOMAIN_SETUP, "Image error: %s: %s",
-					                       file, error->message);
+					  file, error->message);
 		g_error_free (error);
 		return;
 	}
+	
+	store = twitux_tweet_list_get_store ();
 
 	gtk_list_store_set (store, &iter,
 						PIXBUF_AVATAR, pixbuf, -1);
@@ -1086,17 +1208,20 @@ twitux_app_expand_message (const gchar *name,
                            const gchar *tweet,
                            GdkPixbuf   *pixbuf)
 {
-	TwituxAppPriv *priv = GET_PRIV (app);
-	gchar *title_text;
-
-	gtk_widget_show (GTK_WIDGET (priv->expand_box));
+	TwituxAppPriv *priv;
+	gchar 		  *title_text;
+	
+	priv = GET_PRIV (app);
 
 	title_text = g_strdup_printf ("<b>%s</b> - %s", name, date);
 		
 	twitux_label_set_text (TWITUX_LABEL (priv->expand_label), tweet);
 	gtk_label_set_markup (GTK_LABEL (priv->expand_title), title_text);
+	g_free (title_text);
+	
 	if (pixbuf) {
 		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->expand_image), pixbuf);
 	}
-	g_free (title_text);
+	
+	gtk_widget_show (priv->expand_box);
 }
