@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2007 - Daniel Morales <daniminas@gmail.com>
+ * Copyright (C) 2007-2008 Daniel Morales <daniminas@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,13 +16,15 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
+ *
+ * Authors: Daniel Morales <daniminas@gmail.com>
+ *
  */
 
 #include <config.h>
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-util.h>
 #include <libsoup/soup.h>
 
 #include <libtwitux/twitux-debug.h>
@@ -42,43 +44,49 @@
 
 typedef struct {
 	gchar        *src;
-	GtkTreeIter  iter;
+	GtkTreeIter   iter;
 } TwituxImage;
 
 static void network_get_data		(const gchar           *url,
-									 SoupMessageCallbackFn  callback,
+									 SoupSessionCallback    callback,
 									 gpointer               data);
 static void network_post_data		(const gchar           *url,
 									 gchar                 *formdata,
-									 SoupMessageCallbackFn  callback);
+									 SoupSessionCallback    callback);
 static gboolean	network_check_http 	(gint                   status_code);
 static gchar *network_save_data		(SoupMessage           *msg,
 									 const char            *file);
 static void network_parser_free_lists (void);
 
 /* libsoup callbacks */
-static void network_cb_on_login		(SoupMessage           *msg,
+static void network_cb_on_login		(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_post		(SoupMessage           *msg,
+static void network_cb_on_post		(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_message	(SoupMessage           *msg,
+static void network_cb_on_message	(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_timeline	(SoupMessage           *msg,
+static void network_cb_on_timeline	(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_users	    (SoupMessage           *msg,
+static void network_cb_on_users	    (SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_image		(SoupMessage           *msg,
+static void network_cb_on_image		(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_add		(SoupMessage           *msg,
+static void network_cb_on_add		(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
-static void network_cb_on_del		(SoupMessage           *msg,
+static void network_cb_on_del		(SoupSession           *session,
+									 SoupMessage           *msg,
 									 gpointer               user_data);
 static void network_cb_on_auth		(SoupSession           *session,
 									 SoupMessage           *msg,
-									 const char            *auth_type,
-									 const char            *auth_realm,
-									 char                 **username,
-									 char                 **password,
+									 SoupAuth              *auth,
+									 gboolean               retrying,
 									 gpointer               data);
 
 /* Autoreload timeout functions */
@@ -130,7 +138,7 @@ twitux_network_new (void)
 							 &port);
 
 		if (server && server[0]) {
-			SoupUri *suri;
+			SoupURI *suri;
 
 			check_proxy = FALSE;
 			twitux_conf_get_bool (conf,
@@ -220,10 +228,6 @@ twitux_network_login (void)
 					  "authenticate",
 					  G_CALLBACK (network_cb_on_auth),
 					  NULL);
-	g_signal_connect (soup_connection,
-					  "reauthenticate",
-					  G_CALLBACK (network_cb_on_auth),
-					  NULL);
 
 	/* Verify cedentials */
 	network_get_data (TWITUX_API_LOGIN, network_cb_on_login, NULL);
@@ -245,7 +249,7 @@ twitux_network_post_status (const gchar *text)
 {
 	gchar *formdata;
 
-	formdata = g_strdup_printf ("status=%s", text);
+	formdata = g_strdup_printf ("source=twitux&status=%s", text);
 
 	network_post_data (TWITUX_API_POST_STATUS,
 					   formdata,
@@ -379,7 +383,7 @@ twitux_network_get_image (const gchar  *url_image,
 
 	/* Build image file */
 	split_url = g_strsplit (url_image, "?", 2);
-	images_dir = gnome_util_home_file (TWITUX_CACHE_IMAGES);
+	images_dir = g_build_filename (g_get_home_dir (), ".gnome2", TWITUX_CACHE_IMAGES, NULL);
 	image_file = g_strconcat (images_dir,
 							  G_DIR_SEPARATOR_S,
 							  username,
@@ -446,7 +450,7 @@ twitux_network_del_user (TwituxUser *user)
 /* Get data from net */
 static void
 network_get_data (const gchar           *url,
-				  SoupMessageCallbackFn  callback,
+				  SoupSessionCallback    callback,
 				  gpointer               data)
 {
 	SoupMessage *msg;
@@ -463,7 +467,7 @@ network_get_data (const gchar           *url,
 static void
 network_post_data (const gchar           *url,
 				   gchar                 *formdata,
-				   SoupMessageCallbackFn  callback)
+				   SoupSessionCallback    callback)
 {
 	SoupMessage *msg;
 
@@ -471,16 +475,16 @@ network_post_data (const gchar           *url,
 
 	msg = soup_message_new ("POST", url);
 	
-	soup_message_add_header (msg->request_headers,
-							 "X-Twitter-Client", PACKAGE_NAME);
-	soup_message_add_header (msg->request_headers,
-							 "X-Twitter-Client-Version", PACKAGE_VERSION);
-	soup_message_add_header (msg->request_headers,
-							 "X-Twitter-Client-URL", TWITUX_HEADER_URL);
+	soup_message_headers_append (msg->request_headers,
+								 "X-Twitter-Client", PACKAGE_NAME);
+	soup_message_headers_append (msg->request_headers,
+								 "X-Twitter-Client-Version", PACKAGE_VERSION);
+	soup_message_headers_append (msg->request_headers,
+								 "X-Twitter-Client-URL", TWITUX_HEADER_URL);
 
 	soup_message_set_request (msg, 
 							  "application/x-www-form-urlencoded",
-							  SOUP_BUFFER_USER_OWNED,
+							  SOUP_MEMORY_TAKE,
 							  formdata,
 							  strlen (formdata));
 
@@ -520,14 +524,14 @@ network_save_data (SoupMessage *msg,
 	gchar *tmp_file = NULL;
 
 	/* File dir */
-	tmp_file = gnome_util_home_file (file);
+	tmp_file = g_build_filename (g_get_home_dir (), ".gnome2", file, NULL);
 
-	twitux_debug (DEBUG_DOMAIN, "Saving data to: %s",file);
+	twitux_debug (DEBUG_DOMAIN, "Saving data to: %s", tmp_file);
 
 	/* Save */
 	if (g_file_set_contents (tmp_file,
-							 msg->response.body,
-							 msg->response.length,
+							 msg->response_body->data,
+							 msg->response_body->length,
 							 NULL)) {
 		return tmp_file;
 	}
@@ -582,10 +586,8 @@ network_parser_free_lists ()
 static void
 network_cb_on_auth (SoupSession  *session,
 					SoupMessage  *msg,
-					const char   *auth_type,
-					const char   *auth_realm,
-					char        **username,
-					char        **password,
+					SoupAuth     *auth,
+					gboolean      retrying,
 					gpointer      data)
 {
 	TwituxConf *conf;
@@ -603,8 +605,11 @@ network_cb_on_auth (SoupSession  *session,
 	}
 
 #ifdef HAVE_GNOME_KEYRING
-	twitux_keyring_get_password (user_id,
-								 &user_passwd);
+	if (!twitux_keyring_get_password (user_id, &user_passwd))
+	{
+		twitux_app_set_statusbar_msg (
+					_("Could not retrieve password from keyring."));						 	
+	}
 #else
 	twitux_conf_get_string (conf,
 							TWITUX_PREFS_AUTH_PASSWORD,
@@ -612,10 +617,8 @@ network_cb_on_auth (SoupSession  *session,
 #endif
 
 	/* verify that the password has been set */
-	if (!G_STR_EMPTY (user_passwd)) {
-		*username = g_strdup (user_id);
-		*password = g_strdup (user_passwd);
-	}
+	if (!G_STR_EMPTY (user_passwd))
+		soup_auth_authenticate (auth, user_id, user_passwd);
 	
 	if (user_id)
 		g_free (user_id);
@@ -627,7 +630,8 @@ network_cb_on_auth (SoupSession  *session,
 
 /* On verify credentials */
 static void
-network_cb_on_login (SoupMessage *msg,
+network_cb_on_login (SoupSession *session,
+					 SoupMessage *msg,
 					 gpointer     user_data)
 {
 	twitux_debug (DEBUG_DOMAIN,
@@ -645,13 +649,10 @@ network_cb_on_login (SoupMessage *msg,
 
 /* On post a tweet */
 static void
-network_cb_on_post (SoupMessage *msg,
+network_cb_on_post (SoupSession *session,
+					SoupMessage *msg,
 					gpointer     user_data)
 {
-	/* Free buffer memory
-	 * Review: we need to free something more? */
-	g_free (msg->request.body);
-	
 	if (network_check_http (msg->status_code)) {
 		twitux_app_set_statusbar_msg (_("Status Sent"));
 	}
@@ -663,13 +664,10 @@ network_cb_on_post (SoupMessage *msg,
 
 /* On send a direct message */
 static void
-network_cb_on_message (SoupMessage *msg,
+network_cb_on_message (SoupSession *session,
+					   SoupMessage *msg,
 					   gpointer     user_data)
 {
-	/* Free buffer memory
-	 * Review: we need to free something more? */
-	g_free (msg->request.body);
-
 	if (network_check_http (msg->status_code)) {
 		twitux_app_set_statusbar_msg (_("Message Sent"));
 	}
@@ -681,7 +679,8 @@ network_cb_on_message (SoupMessage *msg,
 
 /* On get a timeline */
 static void
-network_cb_on_timeline (SoupMessage *msg,
+network_cb_on_timeline (SoupSession *session,
+						SoupMessage *msg,
 						gpointer     user_data)
 {
 	gchar        *file;
@@ -735,7 +734,8 @@ network_cb_on_timeline (SoupMessage *msg,
 
 /* On get user followers */
 static void
-network_cb_on_users (SoupMessage *msg,
+network_cb_on_users (SoupSession *session,
+					 SoupMessage *msg,
 					 gpointer     user_data)
 {
 	gboolean  friends = GPOINTER_TO_INT(user_data);
@@ -778,7 +778,8 @@ network_cb_on_users (SoupMessage *msg,
 
 /* On get a image */
 static void
-network_cb_on_image (SoupMessage *msg,
+network_cb_on_image (SoupSession *session,
+					 SoupMessage *msg,
 					 gpointer     user_data)
 {
 	TwituxImage *image = (TwituxImage *)user_data;
@@ -790,8 +791,8 @@ network_cb_on_image (SoupMessage *msg,
 	if (network_check_http (msg->status_code)) {
 		/* Save image data */
 		if (g_file_set_contents (image->src,
-								 msg->response.body,
-								 msg->response.length,
+								 msg->response_body->data,
+								 msg->response_body->length,
 								 NULL)) {
 			/* Set image from file here (image_file) */
 			twitux_app_set_image (image->src,image->iter);
@@ -805,7 +806,8 @@ network_cb_on_image (SoupMessage *msg,
 
 /* On add a user */
 static void
-network_cb_on_add (SoupMessage *msg,
+network_cb_on_add (SoupSession *session,
+				   SoupMessage *msg,
 				   gpointer     user_data)
 {
 	TwituxUser *user;
@@ -842,7 +844,8 @@ network_cb_on_add (SoupMessage *msg,
 
 /* On remove a user */
 static void
-network_cb_on_del (SoupMessage *msg,
+network_cb_on_del (SoupSession *session,
+				   SoupMessage *msg,
 				   gpointer     user_data)
 {
 	twitux_debug (DEBUG_DOMAIN,
