@@ -26,6 +26,8 @@
 
 #include "config.h"
 
+#include <string.h>
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <glib/gi18n.h>
@@ -47,6 +49,7 @@ typedef struct {
 	/* Checkbuttons */
 	GtkWidget *expand;
 	GtkWidget *notify;
+	GtkWidget *names;
 	GtkWidget *spell;
 
 	GList     *notify_ids;
@@ -80,7 +83,6 @@ enum {
 };
 
 static void     preferences_setup_widgets          (TwituxPrefs            *prefs);
-static void     preferences_language_setup         (TwituxPrefs            *prefs);
 static void     preferences_languages_add          (TwituxPrefs            *prefs);
 static void     preferences_languages_save         (TwituxPrefs            *prefs);
 static gboolean preferences_languages_save_foreach (GtkTreeModel           *model,
@@ -141,6 +143,10 @@ static void preferences_destroy_cb                 (GtkWidget              *widg
 static void
 preferences_setup_widgets (TwituxPrefs *prefs)
 {
+	preferences_hookup_toggle_button (prefs,
+									  TWITUX_PREFS_TWEETS_SHOW_NAMES,
+									  prefs->names);
+
 	preferences_hookup_toggle_button (prefs,
 									  TWITUX_PREFS_UI_EXPAND_MESSAGES,
 									  prefs->expand);
@@ -458,7 +464,6 @@ preferences_reload_setup (TwituxPrefs *prefs)
 	GtkListStore    *model;
 	GtkTreeIter      iter;
 	GtkCellRenderer *renderer;
-	gint             i;
 	reload_time     *options;
 
 	options = reload_list;
@@ -816,7 +821,7 @@ twitux_preferences_dialog_show (GtkWindow *parent)
 
 	prefs = g_new0 (TwituxPrefs, 1);
 
-	glade = twitux_glade_get_file ("main.glade",
+	glade = twitux_glade_get_file ("preferences_dialog.glade",
 								   "preferences_dialog",
 								   NULL,
 								   "preferences_dialog", &prefs->dialog,
@@ -825,6 +830,7 @@ twitux_preferences_dialog_show (GtkWindow *parent)
 								   "combobox_reload", &prefs->combo_reload,
 								   "expand_checkbutton", &prefs->expand,
 								   "notify_checkbutton", &prefs->notify,
+								   "names_checkbutton", &prefs->names,
 								   "spell_checkbutton", &prefs->spell,
 								   "spell_treeview", &prefs->treeview_spell_checker,
 								   NULL);
